@@ -41,14 +41,20 @@
 #include "../document.h"
 #include "../utils/xmlhandler.h"
 #include "../utils/string_utils.h"
+#include "../config/tellico_config.h"
 
 #include <KLocalizedString>
 
 #include <QTest>
 #include <QNetworkInterface>
 #include <QDate>
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 #include <QTextCodec>
+#else
+#include <QStringEncoder>
+#endif
 #include <QStandardPaths>
+#include <QLoggingCategory>
 
 QTEST_GUILESS_MAIN( TellicoReadTest )
 
@@ -69,6 +75,7 @@ static bool hasNetwork() {
 void TellicoReadTest::initTestCase() {
   QStandardPaths::setTestModeEnabled(true);
   KLocalizedString::setApplicationDomain("tellico");
+  QLoggingCategory::setFilterRules(QStringLiteral("tellico.debug = true\ntellico.info = false"));
   // need to register this first
   Tellico::RegisterCollection<Tellico::Data::BookCollection> registerBook(Tellico::Data::Collection::Book, "book");
   Tellico::RegisterCollection<Tellico::Data::BibtexCollection> registerBibtex(Tellico::Data::Collection::Bibtex, "bibtex");
@@ -226,6 +233,12 @@ void TellicoReadTest::testBibtexCollection() {
   QCOMPARE(loan1->note(), loan2->note());
   QCOMPARE(loan1->uid(), loan2->uid());
   QCOMPARE(loan1->entry()->title(), loan2->entry()->title());
+
+  auto loanEntry = loan1->entry();
+  QCOMPARE(loan1->uid(), borr1->loan(loanEntry)->uid());
+  QVERIFY(borr1->hasEntry(loanEntry));
+  QVERIFY(borr1->removeLoan(loan1));
+  QVERIFY(!borr1->hasEntry(loanEntry));
 }
 
 void TellicoReadTest::testTableData() {
@@ -451,10 +464,17 @@ void TellicoReadTest::testXMLHandler_data() {
                           << QStringLiteral("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<x>value</x>") << true;
 
   QString usa = QString::fromUtf8("США");
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
   QTextCodec* cp1251 = QTextCodec::codecForName("cp1251");
   QByteArray usaBytes = QByteArray("<?xml version=\"1.0\" encoding=\"cp1251\"?>\n<x>")
                       + cp1251->fromUnicode(usa)
                       + QByteArray("</x>");
+#else
+  QStringEncoder toCp1251("cp1251");
+  QByteArray usaBytes = QByteArray("<?xml version=\"1.0\" encoding=\"cp1251\"?>\n<x>")
+                      + QByteArray(toCp1251(usa))
+                      + QByteArray("</x>");
+#endif
   QString usaString = QStringLiteral("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<x>")
                     + usa
                     + QStringLiteral("</x>");
@@ -680,3 +700,52 @@ void TellicoReadTest::testXmlWithJunk() {
   Tellico::Data::CollPtr coll2 = importer2.collection();
   QVERIFY(!coll2);
 }
+
+void TellicoReadTest::testRemote() {
+  Tellico::Config::setImageLocation(Tellico::Config::ImagesInLocalDir);
+  QString tempDirName;
+  QTemporaryDir tempDir;
+  QVERIFY(tempDir.isValid());
+  tempDir.setAutoRemove(true);
+  tempDirName = tempDir.path();
+  QString image = QLatin1String("17b54b2a742c6d342a75f122d615a793.jpeg");
+  QString fileName = tempDirName +      QLatin1String("/with-local-image.tc");
+  QString imageDirName = tempDirName +  QLatin1String("/with-local-image_files/");
+  QString imageFileName = imageDirName + image;
+
+  // copy a collection file that includes an image into the temporary directory
+  QVERIFY(QDir().mkdir(imageDirName));
+  QVERIFY(QFile::copy(QFINDTESTDATA("data/with-local-image.tc"),
+                      fileName));
+  QVERIFY(QFile::copy(QFINDTESTDATA(QLatin1String("data/with-local-image_files/") + image),
+                      imageFileName));
+
+  QUrl localUrl = QUrl::fromLocalFile(fileName);
+  QUrl remoteUrl(QLatin1String("fish://localhost/") + fileName);
+
+  // use the localUrl since the CI doesn't support fish protocol
+  Tellico::Data::Document::self()->openDocument(localUrl);
+
+  // Document has a 500 msec timer to load images
+  qApp->processEvents();
+  QTest::qWait(1000);
+  qApp->processEvents();
+
+  Tellico::Data::CollPtr coll = Tellico::Data::Document::self()->collection();
+  QVERIFY(coll);
+  QVERIFY(!coll->entries().isEmpty());
+  auto entry = coll->entries().front();
+  QVERIFY(entry);
+  auto cover = entry->field(QLatin1String("cover"));
+  QVERIFY(!cover.isEmpty());
+  QCOMPARE(cover, image);
+  QVERIFY(!Tellico::ImageFactory::self()->hasImageInMemory(image));
+  QVERIFY(Tellico::ImageFactory::self()->hasImageInfo(image));
+
+  const Tellico::Data::Image& img = Tellico::ImageFactory::imageById(image);
+  QVERIFY(!img.isNull());
+
+  QVERIFY(QFile::exists(imageFileName));
+  Tellico::ImageFactory::removeImage(image, true);
+  QVERIFY(!QFile::exists(imageFileName));
+}
