@@ -35,7 +35,11 @@
 #include <KLocalizedString>
 
 #include <QDomDocument>
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 #include <QTextCodec>
+#else
+#include <QStringConverter>
+#endif
 
 using namespace Tellico;
 using Tellico::Export::BibtexmlExporter;
@@ -44,7 +48,7 @@ BibtexmlExporter::BibtexmlExporter(Data::CollPtr coll_) : Exporter(coll_) {
 }
 
 QString BibtexmlExporter::formatString() const {
-  return i18n("Bibtexml");
+  return QStringLiteral("Bibtexml");
 }
 
 QString BibtexmlExporter::fileFilter() const {
@@ -98,7 +102,11 @@ QString BibtexmlExporter::text() {
   if(options() & Export::ExportUTF8) {
     encodeStr += QLatin1String("UTF-8");
   } else {
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     encodeStr += QLatin1String(QTextCodec::codecForLocale()->name());
+#else
+    encodeStr += QLatin1String(QStringConverter::nameForEncoding(QStringConverter::System));
+#endif
   }
   encodeStr += QLatin1Char('"');
 
