@@ -48,7 +48,11 @@
 #include <QGroupBox>
 #include <QCheckBox>
 #include <QDomDocument>
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 #include <QTextCodec>
+#else
+#include <QStringConverter>
+#endif
 #include <QVBoxLayout>
 
 #include <algorithm>
@@ -65,7 +69,7 @@ TellicoXMLExporter::~TellicoXMLExporter() {
 }
 
 QString TellicoXMLExporter::formatString() const {
-  return i18n("XML");
+  return QStringLiteral("XML");
 }
 
 QString TellicoXMLExporter::fileFilter() const {
@@ -114,7 +118,11 @@ QDomDocument TellicoXMLExporter::exportXML() const {
   if(options() & Export::ExportUTF8) {
     encodeStr += QLatin1String("UTF-8");
   } else {
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     encodeStr += QLatin1String(QTextCodec::codecForLocale()->name());
+#else
+    encodeStr += QLatin1String(QStringConverter::nameForEncoding(QStringConverter::System));
+#endif
   }
   encodeStr += QLatin1Char('"');
 
@@ -181,7 +189,6 @@ void TellicoXMLExporter::exportCollectionXML(QDomDocument& dom_, QDomElement& pa
 
   if(!m_images.isEmpty() && (options() & Export::ExportImages)) {
     QDomElement imgsElem = dom_.createElement(QStringLiteral("images"));
-    const QStringList imageIds = m_images.values();
     foreach(const QString& id, m_images) {
       exportImageXML(dom_, imgsElem, id);
     }
